@@ -6,9 +6,11 @@ from uw_gradepage.dao import GradePage_DAO
 from restclients_core.exceptions import DataFailureException
 import json
 
+GradePageDao = GradePage_DAO()
+
 
 def get_resource(url, headers={}):
-    response = GradePage_DAO().getURL(url, headers)
+    response = GradePageDao.getURL(url, headers)
 
     if response.status != 200:
         raise DataFailureException(url, response.status, response.data)
